;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "apheleia" "20260613.2149"
  "Reformat buffer stably."
  '((emacs "27"))
  :url "https://github.com/radian-software/apheleia"
  :commit "1c00a5acfb438c833616ebeb134270c01850363f"
  :revdesc "1c00a5acfb43"
  :keywords '("tools")
  :authors '(("Radian LLC" . "contact+apheleia@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+apheleia@radian.codes")))
